// Copyright 2014 Canonical Ltd.
// Licensed under the AGPLv3, see LICENCE file for details.

package network

var (
	NetLookupIP                    = &netLookupIP
	NetListen                      = &netListen
	RunCommand                     = runCommand
	NewEtcNetworkInterfacesBridger = newEtcNetworkInterfacesBridger
	SimulatedOS                    = &simulatedOS
	LaunchIpRouteShow              = &launchIpRouteShow
	LaunchIpRouteShowReal          = launchIpRouteShowReal
)
